@@ -2,7 +2,7 @@ package Plagger::UserAgent;
 use strict;
 use base qw( LWP::UserAgent );
 
-use URI::Fetch 0.05;
+use URI::Fetch 0.06;
 
 sub new {
     my $class = shift;
@@ -22,9 +22,5 @@ sub fetch {
     );
 }
 
-# xxx
-*URI::Fetch::Response::is_success = sub { $_[0]->http_response->is_success };
-*URI::Fetch::Response::is_error   = sub { $_[0]->http_response->is_error };
-
 1;
 
